@@ -17,8 +17,9 @@ from c8y_api.model.binaries import Binaries
 from c8y_api.model.inventory import Inventory, DeviceInventory, DeviceGroupInventory
 from c8y_api.model.measurements import Measurements
 from c8y_api.model.notification2 import Subscriptions, Tokens
-from c8y_api.model.operations import Operations
+from c8y_api.model.operations import Operations, BulkOperations
 from c8y_api.model.tenant_options import TenantOptions
+from c8y_api.model.audit import AuditRecords
 
 
 class CumulocityApi(CumulocityRestApi):
@@ -44,9 +45,11 @@ class CumulocityApi(CumulocityRestApi):
         self.__events = Events(self)
         self.__alarms = Alarms(self)
         self.__operations = Operations(self)
+        self.__bulk_operations = BulkOperations(self)
         self.__tenant_options = TenantOptions(self)
         self.__notification2_subscriptions = Subscriptions(self)
         self.__notification2_tokens = Tokens(self)
+        self.__audit_records = AuditRecords(self)
 
     @property
     def measurements(self) -> Measurements:
@@ -118,6 +121,11 @@ class CumulocityApi(CumulocityRestApi):
         """Provide access to the Operation API."""
         return self.__operations
 
+    @property
+    def bulk_operations(self) -> BulkOperations:
+        """Provide access to the BulkOperation API."""
+        return self.__bulk_operations
+
     @property
     def tenant_options(self) -> TenantOptions:
         """Provide access to the Tenant Options API."""
@@ -132,3 +140,8 @@ class CumulocityApi(CumulocityRestApi):
     def notification2_tokens(self) -> Tokens:
         """Provide access to the Notification 2.0 Tokens API."""
         return self.__notification2_tokens
+
+    @property
+    def audit_records(self) -> AuditRecords:
+        """Provide access to the Audit API."""
+        return self.__audit_records
