@@ -13,7 +13,7 @@ from c8y_api.app import SimpleCumulocityApp
 from c8y_api.model import ManagedObject, Subscription
 from c8y_tk.notification2 import Listener
 
-from tests import RandomNameGenerator
+from testing_util import RandomNameGenerator
 from util import load_dotenv
 
 
