@@ -7,17 +7,16 @@
 from __future__ import annotations
 
 import base64
-import random
-import re
 from typing import List, Set, Any
 from unittest.mock import Mock
 
 import jwt
 import pytest
-from requests import request
 
 from c8y_api.model._base import CumulocityObject
 
+from testing_util import RandomNameGenerator
+
 
 def get_ids(objs: List[CumulocityObject]) -> Set[str]:
     """Isolate the ID from a list of database objects."""
@@ -86,43 +85,6 @@ def random_name() -> str:
     return RandomNameGenerator.random_name()
 
 
-def read_webcontent(source_url, target_path):
-    """Read web content to a local file."""
-    response = request('get', source_url)
-    if 200 <= response.status_code <= 299:
-        with open(target_path, 'wt', encoding='utf-8') as file:
-            file.write(response.text)
-    else:
-        raise RuntimeError('Unable to read web content. Unexpected response from web site: '
-                           f'HTTP {response.status_code} {response.text}')
-
-
-class RandomNameGenerator:
-    """Provides randomly generated names using a public service."""
-
-    wordlist_path = 'wordlist.txt'
-    read_webcontent('https://raw.githubusercontent.com/mike-hearn/useapassphrase/master/js/wordlist.js',
-                    wordlist_path)
-    with open(wordlist_path, 'rt', encoding='utf-8') as file:
-        file.readline()  # skip first line
-        lines = file.readlines()
-    words = [re.sub('[^\\w]', '', line) for line in lines]
-
-    @classmethod
-    def random_name(cls, num: int = 3, sep: str = '_') -> str:
-        """Generate a readable random name from joined random words.
-
-        Args:
-            num (int):  number of random words to concactenate
-            sep (str):  concatenation separator
-
-        Returns:
-            The generated name
-        """
-        words = [random.choice(cls.words) for _ in range(0, num)]
-        return sep.join(words)
-
-
 def b64encode(auth_string: str) -> str:
     """Encode a string with base64. This uses UTF-8 encoding."""
     return base64.b64encode(auth_string.encode('utf-8')).decode('utf-8')
